// GLX functions which need to be simply forwarded
DEF_GLX_PROTO(void,         glXCopyContext,           (Display *dpy, GLXContext src, GLXContext dst, unsigned long mask),src,dst,mask)
DEF_GLX_PROTO(Bool,         glXQueryExtension,        (Display *dpy, int *errorb, int *event),errorb,event)
DEF_GLX_PROTO(Bool,         glXQueryVersion,          (Display *dpy, int *maj, int *min),maj,min)
DEF_GLX_PROTO(Bool,         glXIsDirect,              (Display *dpy, GLXContext ctx),ctx)
DEF_GLX_PROTO(const char*,  glXQueryServerString,     (Display *dpy, int screen, int name),screen,name)
DEF_GLX_PROTO(GLXFBConfig*, glXChooseFBConfig,        (Display *dpy, int screen, const int *attribList, int *nitems),screen,attribList,nitems)
DEF_GLX_PROTO(GLXFBConfig*, glXGetFBConfigs,          (Display *dpy, int screen, int *nelements),screen,nelements)
DEF_GLX_PROTO(int,          glXQueryContext,          (Display *dpy, GLXContext ctx, int attribute, int *value),ctx,attribute,value)
DEF_GLX_PROTO(void,         glXSelectEvent,           (Display *dpy, GLXDrawable drawable, unsigned long mask),drawable,mask)
DEF_GLX_PROTO(void,         glXGetSelectedEvent,      (Display *dpy, GLXDrawable drawable, unsigned long *mask),drawable,mask)
