// OpenGL extension functions needed by primus itself
DEF_GLX_PROTO(void,     glGenBuffers,    (GLsizei n, GLuint *buffers))
DEF_GLX_PROTO(void,     glDeleteBuffers, (GLsizei n, const GLuint *buffers))
DEF_GLX_PROTO(void,     glBindBuffer, (GLenum target, GLuint buffer))
DEF_GLX_PROTO(void,     glBufferData, (GLenum target, GLsizeiptr size, const GLvoid *data, GLenum usage))
DEF_GLX_PROTO(void,     glBufferSubData, (GLenum target, GLintptr offset, GLsizeiptr size, const GLvoid *data))
DEF_GLX_PROTO(GLvoid*,  glMapBuffer,  (GLenum target, GLenum access))
DEF_GLX_PROTO(GLboolean,glUnmapBuffer,(GLenum target))

DEF_GLX_PROTO(GLsync,   glFenceSync, (GLenum condition, GLbitfield flags))
DEF_GLX_PROTO(void,     glDeleteSync,(GLsync sync))
DEF_GLX_PROTO(void,     glWaitSync,  (GLsync sync, GLbitfield flags, GLuint64 timeout))
