// Prototypes for auto-generating forwarders for OpenGL functions
DEF_GLX_PROTO(void, glClearIndex,(GLfloat c), c)
DEF_GLX_PROTO(void, glClearColor,(GLclampf red, GLclampf green, GLclampf blue, GLclampf alpha), red, green, blue, alpha)
DEF_GLX_PROTO(void, glClear,(GLbitfield mask), mask)
DEF_GLX_PROTO(void, glIndexMask,(GLuint mask), mask)
DEF_GLX_PROTO(void, glColorMask,(GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha), red, green, blue, alpha)
DEF_GLX_PROTO(void, glAlphaFunc,(GLenum func, GLclampf ref), func, ref)
DEF_GLX_PROTO(void, glBlendFunc,(GLenum sfactor, GLenum dfactor), sfactor, dfactor)
DEF_GLX_PROTO(void, glLogicOp,(GLenum opcode), opcode)
DEF_GLX_PROTO(void, glCullFace,(GLenum mode), mode)
DEF_GLX_PROTO(void, glFrontFace,(GLenum mode), mode)
DEF_GLX_PROTO(void, glPointSize,(GLfloat size), size)
DEF_GLX_PROTO(void, glLineWidth,(GLfloat width), width)
DEF_GLX_PROTO(void, glLineStipple,(GLint factor, GLushort pattern), factor, pattern)
DEF_GLX_PROTO(void, glPolygonMode,(GLenum face, GLenum mode), face, mode)
DEF_GLX_PROTO(void, glPolygonOffset,(GLfloat factor, GLfloat units), factor, units)
DEF_GLX_PROTO(void, glPolygonStipple,(const GLubyte *mask), mask)
DEF_GLX_PROTO(void, glGetPolygonStipple,(GLubyte *mask), mask)
DEF_GLX_PROTO(void, glEdgeFlag,(GLboolean flag), flag)
DEF_GLX_PROTO(void, glEdgeFlagv,(const GLboolean *flag), flag)
DEF_GLX_PROTO(void, glScissor,(GLint x, GLint y, GLsizei width, GLsizei height), x, y, width, height)
DEF_GLX_PROTO(void, glClipPlane,(GLenum plane, const GLdouble *equation), plane, equation)
DEF_GLX_PROTO(void, glGetClipPlane,(GLenum plane, GLdouble *equation), plane, equation)
DEF_GLX_PROTO(void, glDrawBuffer,(GLenum mode), mode)
DEF_GLX_PROTO(void, glReadBuffer,(GLenum mode), mode)
DEF_GLX_PROTO(void, glEnable,(GLenum cap), cap)
DEF_GLX_PROTO(void, glDisable,(GLenum cap), cap)
DEF_GLX_PROTO(GLboolean, glIsEnabled,(GLenum cap), cap)
DEF_GLX_PROTO(void, glEnableClientState,(GLenum cap), cap)
DEF_GLX_PROTO(void, glDisableClientState,(GLenum cap), cap)
DEF_GLX_PROTO(void, glGetBooleanv,(GLenum pname, GLboolean *params), pname, params)
DEF_GLX_PROTO(void, glGetDoublev,(GLenum pname, GLdouble *params), pname, params)
DEF_GLX_PROTO(void, glGetFloatv,(GLenum pname, GLfloat *params), pname, params)
DEF_GLX_PROTO(void, glGetIntegerv,(GLenum pname, GLint *params), pname, params)
DEF_GLX_PROTO(void, glPushAttrib,(GLbitfield mask), mask)
DEF_GLX_PROTO(void, glPopAttrib,(void))
DEF_GLX_PROTO(void, glPushClientAttrib,(GLbitfield mask), mask)
DEF_GLX_PROTO(void, glPopClientAttrib,(void))
DEF_GLX_PROTO(GLint, glRenderMode,(GLenum mode), mode)
DEF_GLX_PROTO(GLenum, glGetError,(void))
DEF_GLX_PROTO(const GLubyte *, glGetString,(GLenum name), name)
DEF_GLX_PROTO(void, glFinish,(void))
DEF_GLX_PROTO(void, glFlush,(void))
DEF_GLX_PROTO(void, glHint,(GLenum target, GLenum mode), target, mode)
DEF_GLX_PROTO(void, glClearDepth,(GLclampd depth), depth)
DEF_GLX_PROTO(void, glDepthFunc,(GLenum func), func)
DEF_GLX_PROTO(void, glDepthMask,(GLboolean flag), flag)
DEF_GLX_PROTO(void, glDepthRange,(GLclampd near_val, GLclampd far_val), near_val, far_val)
DEF_GLX_PROTO(void, glClearAccum,(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha), red, green, blue, alpha)
DEF_GLX_PROTO(void, glAccum,(GLenum op, GLfloat value), op, value)
DEF_GLX_PROTO(void, glMatrixMode,(GLenum mode), mode)
DEF_GLX_PROTO(void, glOrtho,(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble near_val, GLdouble far_val), left, right, bottom, top, near_val, far_val)
DEF_GLX_PROTO(void, glFrustum,(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble near_val, GLdouble far_val), left, right, bottom, top, near_val, far_val)
DEF_GLX_PROTO(void, glViewport,(GLint x, GLint y, GLsizei width, GLsizei height), x, y, width, height)
DEF_GLX_PROTO(void, glPushMatrix,(void))
DEF_GLX_PROTO(void, glPopMatrix,(void))
DEF_GLX_PROTO(void, glLoadIdentity,(void))
DEF_GLX_PROTO(void, glLoadMatrixd,(const GLdouble *m), m)
DEF_GLX_PROTO(void, glLoadMatrixf,(const GLfloat *m), m)
DEF_GLX_PROTO(void, glMultMatrixd,(const GLdouble *m), m)
DEF_GLX_PROTO(void, glMultMatrixf,(const GLfloat *m), m)
DEF_GLX_PROTO(void, glRotated,(GLdouble angle, GLdouble x, GLdouble y, GLdouble z), angle, x, y, z)
DEF_GLX_PROTO(void, glRotatef,(GLfloat angle, GLfloat x, GLfloat y, GLfloat z), angle, x, y, z)
DEF_GLX_PROTO(void, glScaled,(GLdouble x, GLdouble y, GLdouble z), x, y, z)
DEF_GLX_PROTO(void, glScalef,(GLfloat x, GLfloat y, GLfloat z), x, y, z)
DEF_GLX_PROTO(void, glTranslated,(GLdouble x, GLdouble y, GLdouble z), x, y, z)
DEF_GLX_PROTO(void, glTranslatef,(GLfloat x, GLfloat y, GLfloat z), x, y, z)
DEF_GLX_PROTO(GLboolean, glIsList,(GLuint list), list)
DEF_GLX_PROTO(void, glDeleteLists,(GLuint list, GLsizei range), list, range)
DEF_GLX_PROTO(GLuint, glGenLists,(GLsizei range), range)
DEF_GLX_PROTO(void, glNewList,(GLuint list, GLenum mode), list, mode)
DEF_GLX_PROTO(void, glEndList,(void))
DEF_GLX_PROTO(void, glCallList,(GLuint list), list)
DEF_GLX_PROTO(void, glCallLists,(GLsizei n, GLenum type, const GLvoid *lists), n, type, lists)
DEF_GLX_PROTO(void, glListBase,(GLuint base), base)
DEF_GLX_PROTO(void, glBegin,(GLenum mode), mode)
DEF_GLX_PROTO(void, glEnd,(void))
DEF_GLX_PROTO(void, glVertex2d,(GLdouble x, GLdouble y), x, y)
DEF_GLX_PROTO(void, glVertex2f,(GLfloat x, GLfloat y), x, y)
DEF_GLX_PROTO(void, glVertex2i,(GLint x, GLint y), x, y)
DEF_GLX_PROTO(void, glVertex2s,(GLshort x, GLshort y), x, y)
DEF_GLX_PROTO(void, glVertex3d,(GLdouble x, GLdouble y, GLdouble z), x, y, z)
DEF_GLX_PROTO(void, glVertex3f,(GLfloat x, GLfloat y, GLfloat z), x, y, z)
DEF_GLX_PROTO(void, glVertex3i,(GLint x, GLint y, GLint z), x, y, z)
DEF_GLX_PROTO(void, glVertex3s,(GLshort x, GLshort y, GLshort z), x, y, z)
DEF_GLX_PROTO(void, glVertex4d,(GLdouble x, GLdouble y, GLdouble z, GLdouble w), x, y, z, w)
DEF_GLX_PROTO(void, glVertex4f,(GLfloat x, GLfloat y, GLfloat z, GLfloat w), x, y, z, w)
DEF_GLX_PROTO(void, glVertex4i,(GLint x, GLint y, GLint z, GLint w), x, y, z, w)
DEF_GLX_PROTO(void, glVertex4s,(GLshort x, GLshort y, GLshort z, GLshort w), x, y, z, w)
DEF_GLX_PROTO(void, glVertex2dv,(const GLdouble *v), v)
DEF_GLX_PROTO(void, glVertex2fv,(const GLfloat *v), v)
DEF_GLX_PROTO(void, glVertex2iv,(const GLint *v), v)
DEF_GLX_PROTO(void, glVertex2sv,(const GLshort *v), v)
DEF_GLX_PROTO(void, glVertex3dv,(const GLdouble *v), v)
DEF_GLX_PROTO(void, glVertex3fv,(const GLfloat *v), v)
DEF_GLX_PROTO(void, glVertex3iv,(const GLint *v), v)
DEF_GLX_PROTO(void, glVertex3sv,(const GLshort *v), v)
DEF_GLX_PROTO(void, glVertex4dv,(const GLdouble *v), v)
DEF_GLX_PROTO(void, glVertex4fv,(const GLfloat *v), v)
DEF_GLX_PROTO(void, glVertex4iv,(const GLint *v), v)
DEF_GLX_PROTO(void, glVertex4sv,(const GLshort *v), v)
DEF_GLX_PROTO(void, glNormal3b,(GLbyte nx, GLbyte ny, GLbyte nz), nx, ny, nz)
DEF_GLX_PROTO(void, glNormal3d,(GLdouble nx, GLdouble ny, GLdouble nz), nx, ny, nz)
DEF_GLX_PROTO(void, glNormal3f,(GLfloat nx, GLfloat ny, GLfloat nz), nx, ny, nz)
DEF_GLX_PROTO(void, glNormal3i,(GLint nx, GLint ny, GLint nz), nx, ny, nz)
DEF_GLX_PROTO(void, glNormal3s,(GLshort nx, GLshort ny, GLshort nz), nx, ny, nz)
DEF_GLX_PROTO(void, glNormal3bv,(const GLbyte *v), v)
DEF_GLX_PROTO(void, glNormal3dv,(const GLdouble *v), v)
DEF_GLX_PROTO(void, glNormal3fv,(const GLfloat *v), v)
DEF_GLX_PROTO(void, glNormal3iv,(const GLint *v), v)
DEF_GLX_PROTO(void, glNormal3sv,(const GLshort *v), v)
DEF_GLX_PROTO(void, glIndexd,(GLdouble c), c)
DEF_GLX_PROTO(void, glIndexf,(GLfloat c), c)
DEF_GLX_PROTO(void, glIndexi,(GLint c), c)
DEF_GLX_PROTO(void, glIndexs,(GLshort c), c)
DEF_GLX_PROTO(void, glIndexub,(GLubyte c), c)
DEF_GLX_PROTO(void, glIndexdv,(const GLdouble *c), c)
DEF_GLX_PROTO(void, glIndexfv,(const GLfloat *c), c)
DEF_GLX_PROTO(void, glIndexiv,(const GLint *c), c)
DEF_GLX_PROTO(void, glIndexsv,(const GLshort *c), c)
DEF_GLX_PROTO(void, glIndexubv,(const GLubyte *c), c)
DEF_GLX_PROTO(void, glColor3b,(GLbyte red, GLbyte green, GLbyte blue), red, green, blue)
DEF_GLX_PROTO(void, glColor3d,(GLdouble red, GLdouble green, GLdouble blue), red, green, blue)
DEF_GLX_PROTO(void, glColor3f,(GLfloat red, GLfloat green, GLfloat blue), red, green, blue)
DEF_GLX_PROTO(void, glColor3i,(GLint red, GLint green, GLint blue), red, green, blue)
DEF_GLX_PROTO(void, glColor3s,(GLshort red, GLshort green, GLshort blue), red, green, blue)
DEF_GLX_PROTO(void, glColor3ub,(GLubyte red, GLubyte green, GLubyte blue), red, green, blue)
DEF_GLX_PROTO(void, glColor3ui,(GLuint red, GLuint green, GLuint blue), red, green, blue)
DEF_GLX_PROTO(void, glColor3us,(GLushort red, GLushort green, GLushort blue), red, green, blue)
DEF_GLX_PROTO(void, glColor4b,(GLbyte red, GLbyte green, GLbyte blue, GLbyte alpha), red, green, blue, alpha)
DEF_GLX_PROTO(void, glColor4d,(GLdouble red, GLdouble green, GLdouble blue, GLdouble alpha), red, green, blue, alpha)
DEF_GLX_PROTO(void, glColor4f,(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha), red, green, blue, alpha)
DEF_GLX_PROTO(void, glColor4i,(GLint red, GLint green, GLint blue, GLint alpha), red, green, blue, alpha)
DEF_GLX_PROTO(void, glColor4s,(GLshort red, GLshort green, GLshort blue, GLshort alpha), red, green, blue, alpha)
DEF_GLX_PROTO(void, glColor4ub,(GLubyte red, GLubyte green, GLubyte blue, GLubyte alpha), red, green, blue, alpha)
DEF_GLX_PROTO(void, glColor4ui,(GLuint red, GLuint green, GLuint blue, GLuint alpha), red, green, blue, alpha)
DEF_GLX_PROTO(void, glColor4us,(GLushort red, GLushort green, GLushort blue, GLushort alpha), red, green, blue, alpha)
DEF_GLX_PROTO(void, glColor3bv,(const GLbyte *v), v)
DEF_GLX_PROTO(void, glColor3dv,(const GLdouble *v), v)
DEF_GLX_PROTO(void, glColor3fv,(const GLfloat *v), v)
DEF_GLX_PROTO(void, glColor3iv,(const GLint *v), v)
DEF_GLX_PROTO(void, glColor3sv,(const GLshort *v), v)
DEF_GLX_PROTO(void, glColor3ubv,(const GLubyte *v), v)
DEF_GLX_PROTO(void, glColor3uiv,(const GLuint *v), v)
DEF_GLX_PROTO(void, glColor3usv,(const GLushort *v), v)
DEF_GLX_PROTO(void, glColor4bv,(const GLbyte *v), v)
DEF_GLX_PROTO(void, glColor4dv,(const GLdouble *v), v)
DEF_GLX_PROTO(void, glColor4fv,(const GLfloat *v), v)
DEF_GLX_PROTO(void, glColor4iv,(const GLint *v), v)
DEF_GLX_PROTO(void, glColor4sv,(const GLshort *v), v)
DEF_GLX_PROTO(void, glColor4ubv,(const GLubyte *v), v)
DEF_GLX_PROTO(void, glColor4uiv,(const GLuint *v), v)
DEF_GLX_PROTO(void, glColor4usv,(const GLushort *v), v)
DEF_GLX_PROTO(void, glTexCoord1d,(GLdouble s), s)
DEF_GLX_PROTO(void, glTexCoord1f,(GLfloat s), s)
DEF_GLX_PROTO(void, glTexCoord1i,(GLint s), s)
DEF_GLX_PROTO(void, glTexCoord1s,(GLshort s), s)
DEF_GLX_PROTO(void, glTexCoord2d,(GLdouble s, GLdouble t), s, t)
DEF_GLX_PROTO(void, glTexCoord2f,(GLfloat s, GLfloat t), s, t)
DEF_GLX_PROTO(void, glTexCoord2i,(GLint s, GLint t), s, t)
DEF_GLX_PROTO(void, glTexCoord2s,(GLshort s, GLshort t), s, t)
DEF_GLX_PROTO(void, glTexCoord3d,(GLdouble s, GLdouble t, GLdouble r), s, t, r)
DEF_GLX_PROTO(void, glTexCoord3f,(GLfloat s, GLfloat t, GLfloat r), s, t, r)
DEF_GLX_PROTO(void, glTexCoord3i,(GLint s, GLint t, GLint r), s, t, r)
DEF_GLX_PROTO(void, glTexCoord3s,(GLshort s, GLshort t, GLshort r), s, t, r)
DEF_GLX_PROTO(void, glTexCoord4d,(GLdouble s, GLdouble t, GLdouble r, GLdouble q), s, t, r, q)
DEF_GLX_PROTO(void, glTexCoord4f,(GLfloat s, GLfloat t, GLfloat r, GLfloat q), s, t, r, q)
DEF_GLX_PROTO(void, glTexCoord4i,(GLint s, GLint t, GLint r, GLint q), s, t, r, q)
DEF_GLX_PROTO(void, glTexCoord4s,(GLshort s, GLshort t, GLshort r, GLshort q), s, t, r, q)
DEF_GLX_PROTO(void, glTexCoord1dv,(const GLdouble *v), v)
DEF_GLX_PROTO(void, glTexCoord1fv,(const GLfloat *v), v)
DEF_GLX_PROTO(void, glTexCoord1iv,(const GLint *v), v)
DEF_GLX_PROTO(void, glTexCoord1sv,(const GLshort *v), v)
DEF_GLX_PROTO(void, glTexCoord2dv,(const GLdouble *v), v)
DEF_GLX_PROTO(void, glTexCoord2fv,(const GLfloat *v), v)
DEF_GLX_PROTO(void, glTexCoord2iv,(const GLint *v), v)
DEF_GLX_PROTO(void, glTexCoord2sv,(const GLshort *v), v)
DEF_GLX_PROTO(void, glTexCoord3dv,(const GLdouble *v), v)
DEF_GLX_PROTO(void, glTexCoord3fv,(const GLfloat *v), v)
DEF_GLX_PROTO(void, glTexCoord3iv,(const GLint *v), v)
DEF_GLX_PROTO(void, glTexCoord3sv,(const GLshort *v), v)
DEF_GLX_PROTO(void, glTexCoord4dv,(const GLdouble *v), v)
DEF_GLX_PROTO(void, glTexCoord4fv,(const GLfloat *v), v)
DEF_GLX_PROTO(void, glTexCoord4iv,(const GLint *v), v)
DEF_GLX_PROTO(void, glTexCoord4sv,(const GLshort *v), v)
DEF_GLX_PROTO(void, glRasterPos2d,(GLdouble x, GLdouble y), x, y)
DEF_GLX_PROTO(void, glRasterPos2f,(GLfloat x, GLfloat y), x, y)
DEF_GLX_PROTO(void, glRasterPos2i,(GLint x, GLint y), x, y)
DEF_GLX_PROTO(void, glRasterPos2s,(GLshort x, GLshort y), x, y)
DEF_GLX_PROTO(void, glRasterPos3d,(GLdouble x, GLdouble y, GLdouble z), x, y, z)
DEF_GLX_PROTO(void, glRasterPos3f,(GLfloat x, GLfloat y, GLfloat z), x, y, z)
DEF_GLX_PROTO(void, glRasterPos3i,(GLint x, GLint y, GLint z), x, y, z)
DEF_GLX_PROTO(void, glRasterPos3s,(GLshort x, GLshort y, GLshort z), x, y, z)
DEF_GLX_PROTO(void, glRasterPos4d,(GLdouble x, GLdouble y, GLdouble z, GLdouble w), x, y, z, w)
DEF_GLX_PROTO(void, glRasterPos4f,(GLfloat x, GLfloat y, GLfloat z, GLfloat w), x, y, z, w)
DEF_GLX_PROTO(void, glRasterPos4i,(GLint x, GLint y, GLint z, GLint w), x, y, z, w)
DEF_GLX_PROTO(void, glRasterPos4s,(GLshort x, GLshort y, GLshort z, GLshort w), x, y, z, w)
DEF_GLX_PROTO(void, glRasterPos2dv,(const GLdouble *v), v)
DEF_GLX_PROTO(void, glRasterPos2fv,(const GLfloat *v), v)
DEF_GLX_PROTO(void, glRasterPos2iv,(const GLint *v), v)
DEF_GLX_PROTO(void, glRasterPos2sv,(const GLshort *v), v)
DEF_GLX_PROTO(void, glRasterPos3dv,(const GLdouble *v), v)
DEF_GLX_PROTO(void, glRasterPos3fv,(const GLfloat *v), v)
DEF_GLX_PROTO(void, glRasterPos3iv,(const GLint *v), v)
DEF_GLX_PROTO(void, glRasterPos3sv,(const GLshort *v), v)
DEF_GLX_PROTO(void, glRasterPos4dv,(const GLdouble *v), v)
DEF_GLX_PROTO(void, glRasterPos4fv,(const GLfloat *v), v)
DEF_GLX_PROTO(void, glRasterPos4iv,(const GLint *v), v)
DEF_GLX_PROTO(void, glRasterPos4sv,(const GLshort *v), v)
DEF_GLX_PROTO(void, glRectd,(GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2), x1, y1, x2, y2)
DEF_GLX_PROTO(void, glRectf,(GLfloat x1, GLfloat y1, GLfloat x2, GLfloat y2), x1, y1, x2, y2)
DEF_GLX_PROTO(void, glRecti,(GLint x1, GLint y1, GLint x2, GLint y2), x1, y1, x2, y2)
DEF_GLX_PROTO(void, glRects,(GLshort x1, GLshort y1, GLshort x2, GLshort y2), x1, y1, x2, y2)
DEF_GLX_PROTO(void, glRectdv,(const GLdouble *v1, const GLdouble *v2), v1, v2)
DEF_GLX_PROTO(void, glRectfv,(const GLfloat *v1, const GLfloat *v2), v1, v2)
DEF_GLX_PROTO(void, glRectiv,(const GLint *v1, const GLint *v2), v1, v2)
DEF_GLX_PROTO(void, glRectsv,(const GLshort *v1, const GLshort *v2), v1, v2)
DEF_GLX_PROTO(void, glVertexPointer,(GLint size, GLenum type, GLsizei stride, const GLvoid *ptr), size, type, stride, ptr)
DEF_GLX_PROTO(void, glNormalPointer,(GLenum type, GLsizei stride, const GLvoid *ptr), type, stride, ptr)
DEF_GLX_PROTO(void, glColorPointer,(GLint size, GLenum type, GLsizei stride, const GLvoid *ptr), size, type, stride, ptr)
DEF_GLX_PROTO(void, glIndexPointer,(GLenum type, GLsizei stride, const GLvoid *ptr), type, stride, ptr)
DEF_GLX_PROTO(void, glTexCoordPointer,(GLint size, GLenum type, GLsizei stride, const GLvoid *ptr), size, type, stride, ptr)
DEF_GLX_PROTO(void, glEdgeFlagPointer,(GLsizei stride, const GLvoid *ptr), stride, ptr)
DEF_GLX_PROTO(void, glGetPointerv,(GLenum pname, GLvoid **params), pname, params)
DEF_GLX_PROTO(void, glArrayElement,(GLint i), i)
DEF_GLX_PROTO(void, glDrawArrays,(GLenum mode, GLint first, GLsizei count), mode, first, count)
DEF_GLX_PROTO(void, glDrawElements,(GLenum mode, GLsizei count, GLenum type, const GLvoid *indices), mode, count, type, indices)
DEF_GLX_PROTO(void, glInterleavedArrays,(GLenum format, GLsizei stride, const GLvoid *pointer), format, stride, pointer)
DEF_GLX_PROTO(void, glShadeModel,(GLenum mode), mode)
DEF_GLX_PROTO(void, glLightf,(GLenum light, GLenum pname, GLfloat param), light, pname, param)
DEF_GLX_PROTO(void, glLighti,(GLenum light, GLenum pname, GLint param), light, pname, param)
DEF_GLX_PROTO(void, glLightfv,(GLenum light, GLenum pname, const GLfloat *params), light, pname, params)
DEF_GLX_PROTO(void, glLightiv,(GLenum light, GLenum pname, const GLint *params), light, pname, params)
DEF_GLX_PROTO(void, glGetLightfv,(GLenum light, GLenum pname, GLfloat *params), light, pname, params)
DEF_GLX_PROTO(void, glGetLightiv,(GLenum light, GLenum pname, GLint *params), light, pname, params)
DEF_GLX_PROTO(void, glLightModelf,(GLenum pname, GLfloat param), pname, param)
DEF_GLX_PROTO(void, glLightModeli,(GLenum pname, GLint param), pname, param)
DEF_GLX_PROTO(void, glLightModelfv,(GLenum pname, const GLfloat *params), pname, params)
DEF_GLX_PROTO(void, glLightModeliv,(GLenum pname, const GLint *params), pname, params)
DEF_GLX_PROTO(void, glMaterialf,(GLenum face, GLenum pname, GLfloat param), face, pname, param)
DEF_GLX_PROTO(void, glMateriali,(GLenum face, GLenum pname, GLint param), face, pname, param)
DEF_GLX_PROTO(void, glMaterialfv,(GLenum face, GLenum pname, const GLfloat *params), face, pname, params)
DEF_GLX_PROTO(void, glMaterialiv,(GLenum face, GLenum pname, const GLint *params), face, pname, params)
DEF_GLX_PROTO(void, glGetMaterialfv,(GLenum face, GLenum pname, GLfloat *params), face, pname, params)
DEF_GLX_PROTO(void, glGetMaterialiv,(GLenum face, GLenum pname, GLint *params), face, pname, params)
DEF_GLX_PROTO(void, glColorMaterial,(GLenum face, GLenum mode), face, mode)
DEF_GLX_PROTO(void, glPixelZoom,(GLfloat xfactor, GLfloat yfactor), xfactor, yfactor)
DEF_GLX_PROTO(void, glPixelStoref,(GLenum pname, GLfloat param), pname, param)
DEF_GLX_PROTO(void, glPixelStorei,(GLenum pname, GLint param), pname, param)
DEF_GLX_PROTO(void, glPixelTransferf,(GLenum pname, GLfloat param), pname, param)
DEF_GLX_PROTO(void, glPixelTransferi,(GLenum pname, GLint param), pname, param)
DEF_GLX_PROTO(void, glPixelMapfv,(GLenum map, GLsizei mapsize, const GLfloat *values), map, mapsize, values)
DEF_GLX_PROTO(void, glPixelMapuiv,(GLenum map, GLsizei mapsize, const GLuint *values), map, mapsize, values)
DEF_GLX_PROTO(void, glPixelMapusv,(GLenum map, GLsizei mapsize, const GLushort *values), map, mapsize, values)
DEF_GLX_PROTO(void, glGetPixelMapfv,(GLenum map, GLfloat *values), map, values)
DEF_GLX_PROTO(void, glGetPixelMapuiv,(GLenum map, GLuint *values), map, values)
DEF_GLX_PROTO(void, glGetPixelMapusv,(GLenum map, GLushort *values), map, values)
DEF_GLX_PROTO(void, glBitmap,(GLsizei width, GLsizei height, GLfloat xorig, GLfloat yorig, GLfloat xmove, GLfloat ymove, const GLubyte *bitmap), width, height, xorig, yorig, xmove, ymove, bitmap)
DEF_GLX_PROTO(void, glReadPixels,(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLvoid *pixels), x, y, width, height, format, type, pixels)
DEF_GLX_PROTO(void, glDrawPixels,(GLsizei width, GLsizei height, GLenum format, GLenum type, const GLvoid *pixels), width, height, format, type, pixels)
DEF_GLX_PROTO(void, glCopyPixels,(GLint x, GLint y, GLsizei width, GLsizei height, GLenum type), x, y, width, height, type)
DEF_GLX_PROTO(void, glStencilFunc,(GLenum func, GLint ref, GLuint mask), func, ref, mask)
DEF_GLX_PROTO(void, glStencilMask,(GLuint mask), mask)
DEF_GLX_PROTO(void, glStencilOp,(GLenum fail, GLenum zfail, GLenum zpass), fail, zfail, zpass)
DEF_GLX_PROTO(void, glClearStencil,(GLint s), s)
DEF_GLX_PROTO(void, glTexGend,(GLenum coord, GLenum pname, GLdouble param), coord, pname, param)
DEF_GLX_PROTO(void, glTexGenf,(GLenum coord, GLenum pname, GLfloat param), coord, pname, param)
DEF_GLX_PROTO(void, glTexGeni,(GLenum coord, GLenum pname, GLint param), coord, pname, param)
DEF_GLX_PROTO(void, glTexGendv,(GLenum coord, GLenum pname, const GLdouble *params), coord, pname, params)
DEF_GLX_PROTO(void, glTexGenfv,(GLenum coord, GLenum pname, const GLfloat *params), coord, pname, params)
DEF_GLX_PROTO(void, glTexGeniv,(GLenum coord, GLenum pname, const GLint *params), coord, pname, params)
DEF_GLX_PROTO(void, glGetTexGendv,(GLenum coord, GLenum pname, GLdouble *params), coord, pname, params)
DEF_GLX_PROTO(void, glGetTexGenfv,(GLenum coord, GLenum pname, GLfloat *params), coord, pname, params)
DEF_GLX_PROTO(void, glGetTexGeniv,(GLenum coord, GLenum pname, GLint *params), coord, pname, params)
DEF_GLX_PROTO(void, glTexEnvf,(GLenum target, GLenum pname, GLfloat param), target, pname, param)
DEF_GLX_PROTO(void, glTexEnvi,(GLenum target, GLenum pname, GLint param), target, pname, param)
DEF_GLX_PROTO(void, glTexEnvfv,(GLenum target, GLenum pname, const GLfloat *params), target, pname, params)
DEF_GLX_PROTO(void, glTexEnviv,(GLenum target, GLenum pname, const GLint *params), target, pname, params)
DEF_GLX_PROTO(void, glGetTexEnvfv,(GLenum target, GLenum pname, GLfloat *params), target, pname, params)
DEF_GLX_PROTO(void, glGetTexEnviv,(GLenum target, GLenum pname, GLint *params), target, pname, params)
DEF_GLX_PROTO(void, glTexParameterf,(GLenum target, GLenum pname, GLfloat param), target, pname, param)
DEF_GLX_PROTO(void, glTexParameteri,(GLenum target, GLenum pname, GLint param), target, pname, param)
DEF_GLX_PROTO(void, glTexParameterfv,(GLenum target, GLenum pname, const GLfloat *params), target, pname, params)
DEF_GLX_PROTO(void, glTexParameteriv,(GLenum target, GLenum pname, const GLint *params), target, pname, params)
DEF_GLX_PROTO(void, glGetTexParameterfv,(GLenum target, GLenum pname, GLfloat *params), target, pname, params)
DEF_GLX_PROTO(void, glGetTexParameteriv,(GLenum target, GLenum pname, GLint *params), target, pname, params)
DEF_GLX_PROTO(void, glGetTexLevelParameterfv,(GLenum target, GLint level, GLenum pname, GLfloat *params), target, level, pname, params)
DEF_GLX_PROTO(void, glGetTexLevelParameteriv,(GLenum target, GLint level, GLenum pname, GLint *params), target, level, pname, params)
DEF_GLX_PROTO(void, glTexImage1D,(GLenum target, GLint level, GLint internalFormat, GLsizei width, GLint border, GLenum format, GLenum type, const GLvoid *pixels), target, level, internalFormat, width, border, format, type, pixels)
DEF_GLX_PROTO(void, glTexImage2D,(GLenum target, GLint level, GLint internalFormat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const GLvoid *pixels), target, level, internalFormat, width, height, border, format, type, pixels)
DEF_GLX_PROTO(void, glGetTexImage,(GLenum target, GLint level, GLenum format, GLenum type, GLvoid *pixels), target, level, format, type, pixels)
DEF_GLX_PROTO(void, glGenTextures,(GLsizei n, GLuint *textures), n, textures)
DEF_GLX_PROTO(void, glDeleteTextures,(GLsizei n, const GLuint *textures), n, textures)
DEF_GLX_PROTO(void, glBindTexture,(GLenum target, GLuint texture), target, texture)
DEF_GLX_PROTO(void, glPrioritizeTextures,(GLsizei n, const GLuint *textures, const GLclampf *priorities), n, textures, priorities)
DEF_GLX_PROTO(GLboolean, glAreTexturesResident,(GLsizei n, const GLuint *textures, GLboolean *residences), n, textures, residences)
DEF_GLX_PROTO(GLboolean, glIsTexture,(GLuint texture), texture)
DEF_GLX_PROTO(void, glTexSubImage1D,(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const GLvoid *pixels), target, level, xoffset, width, format, type, pixels)
DEF_GLX_PROTO(void, glTexSubImage2D,(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const GLvoid *pixels), target, level, xoffset, yoffset, width, height, format, type, pixels)
DEF_GLX_PROTO(void, glCopyTexImage1D,(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border), target, level, internalformat, x, y, width, border)
DEF_GLX_PROTO(void, glCopyTexImage2D,(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border), target, level, internalformat, x, y, width, height, border)
DEF_GLX_PROTO(void, glCopyTexSubImage1D,(GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width), target, level, xoffset, x, y, width)
DEF_GLX_PROTO(void, glCopyTexSubImage2D,(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height), target, level, xoffset, yoffset, x, y, width, height)
DEF_GLX_PROTO(void, glMap1d,(GLenum target, GLdouble u1, GLdouble u2, GLint stride, GLint order, const GLdouble *points), target, u1, u2, stride, order, points)
DEF_GLX_PROTO(void, glMap1f,(GLenum target, GLfloat u1, GLfloat u2, GLint stride, GLint order, const GLfloat *points), target, u1, u2, stride, order, points)
DEF_GLX_PROTO(void, glMap2d,(GLenum target, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, const GLdouble *points), target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points)
DEF_GLX_PROTO(void, glMap2f,(GLenum target, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, const GLfloat *points), target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points)
DEF_GLX_PROTO(void, glGetMapdv,(GLenum target, GLenum query, GLdouble *v), target, query, v)
DEF_GLX_PROTO(void, glGetMapfv,(GLenum target, GLenum query, GLfloat *v), target, query, v)
DEF_GLX_PROTO(void, glGetMapiv,(GLenum target, GLenum query, GLint *v), target, query, v)
DEF_GLX_PROTO(void, glEvalCoord1d,(GLdouble u), u)
DEF_GLX_PROTO(void, glEvalCoord1f,(GLfloat u), u)
DEF_GLX_PROTO(void, glEvalCoord1dv,(const GLdouble *u), u)
DEF_GLX_PROTO(void, glEvalCoord1fv,(const GLfloat *u), u)
DEF_GLX_PROTO(void, glEvalCoord2d,(GLdouble u, GLdouble v), u, v)
DEF_GLX_PROTO(void, glEvalCoord2f,(GLfloat u, GLfloat v), u, v)
DEF_GLX_PROTO(void, glEvalCoord2dv,(const GLdouble *u), u)
DEF_GLX_PROTO(void, glEvalCoord2fv,(const GLfloat *u), u)
DEF_GLX_PROTO(void, glMapGrid1d,(GLint un, GLdouble u1, GLdouble u2), un, u1, u2)
DEF_GLX_PROTO(void, glMapGrid1f,(GLint un, GLfloat u1, GLfloat u2), un, u1, u2)
DEF_GLX_PROTO(void, glMapGrid2d,(GLint un, GLdouble u1, GLdouble u2, GLint vn, GLdouble v1, GLdouble v2), un, u1, u2, vn, v1, v2)
DEF_GLX_PROTO(void, glMapGrid2f,(GLint un, GLfloat u1, GLfloat u2, GLint vn, GLfloat v1, GLfloat v2), un, u1, u2, vn, v1, v2)
DEF_GLX_PROTO(void, glEvalPoint1,(GLint i), i)
DEF_GLX_PROTO(void, glEvalPoint2,(GLint i, GLint j), i, j)
DEF_GLX_PROTO(void, glEvalMesh1,(GLenum mode, GLint i1, GLint i2), mode, i1, i2)
DEF_GLX_PROTO(void, glEvalMesh2,(GLenum mode, GLint i1, GLint i2, GLint j1, GLint j2), mode, i1, i2, j1, j2)
DEF_GLX_PROTO(void, glFogf,(GLenum pname, GLfloat param), pname, param)
DEF_GLX_PROTO(void, glFogi,(GLenum pname, GLint param), pname, param)
DEF_GLX_PROTO(void, glFogfv,(GLenum pname, const GLfloat *params), pname, params)
DEF_GLX_PROTO(void, glFogiv,(GLenum pname, const GLint *params), pname, params)
DEF_GLX_PROTO(void, glFeedbackBuffer,(GLsizei size, GLenum type, GLfloat *buffer), size, type, buffer)
DEF_GLX_PROTO(void, glPassThrough,(GLfloat token), token)
DEF_GLX_PROTO(void, glSelectBuffer,(GLsizei size, GLuint *buffer), size, buffer)
DEF_GLX_PROTO(void, glInitNames,(void))
DEF_GLX_PROTO(void, glLoadName,(GLuint name), name)
DEF_GLX_PROTO(void, glPushName,(GLuint name), name)
DEF_GLX_PROTO(void, glPopName,(void))
DEF_GLX_PROTO(void, glDrawRangeElements,(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const GLvoid *indices), mode, start, end, count, type, indices)
DEF_GLX_PROTO(void, glTexImage3D,(GLenum target, GLint level, GLint internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const GLvoid *pixels), target, level, internalFormat, width, height, depth, border, format, type, pixels)
DEF_GLX_PROTO(void, glTexSubImage3D,(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const GLvoid *pixels), target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels)
DEF_GLX_PROTO(void, glCopyTexSubImage3D,(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height), target, level, xoffset, yoffset, zoffset, x, y, width, height)
DEF_GLX_PROTO(void, glColorTable,(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const GLvoid *table), target, internalformat, width, format, type, table)
DEF_GLX_PROTO(void, glColorSubTable,(GLenum target, GLsizei start, GLsizei count, GLenum format, GLenum type, const GLvoid *data), target, start, count, format, type, data)
DEF_GLX_PROTO(void, glColorTableParameteriv,(GLenum target, GLenum pname, const GLint *params), target, pname, params)
DEF_GLX_PROTO(void, glColorTableParameterfv,(GLenum target, GLenum pname, const GLfloat *params), target, pname, params)
DEF_GLX_PROTO(void, glCopyColorSubTable,(GLenum target, GLsizei start, GLint x, GLint y, GLsizei width), target, start, x, y, width)
DEF_GLX_PROTO(void, glCopyColorTable,(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width), target, internalformat, x, y, width)
DEF_GLX_PROTO(void, glGetColorTable,(GLenum target, GLenum format, GLenum type, GLvoid *table), target, format, type, table)
DEF_GLX_PROTO(void, glGetColorTableParameterfv,(GLenum target, GLenum pname, GLfloat *params), target, pname, params)
DEF_GLX_PROTO(void, glGetColorTableParameteriv,(GLenum target, GLenum pname, GLint *params), target, pname, params)
DEF_GLX_PROTO(void, glBlendEquation,(GLenum mode), mode)
DEF_GLX_PROTO(void, glBlendColor,(GLclampf red, GLclampf green, GLclampf blue, GLclampf alpha), red, green, blue, alpha)
DEF_GLX_PROTO(void, glHistogram,(GLenum target, GLsizei width, GLenum internalformat, GLboolean sink), target, width, internalformat, sink)
DEF_GLX_PROTO(void, glResetHistogram,(GLenum target), target)
DEF_GLX_PROTO(void, glGetHistogram,(GLenum target, GLboolean reset, GLenum format, GLenum type, GLvoid *values), target, reset, format, type, values)
DEF_GLX_PROTO(void, glGetHistogramParameterfv,(GLenum target, GLenum pname, GLfloat *params), target, pname, params)
DEF_GLX_PROTO(void, glGetHistogramParameteriv,(GLenum target, GLenum pname, GLint *params), target, pname, params)
DEF_GLX_PROTO(void, glMinmax,(GLenum target, GLenum internalformat, GLboolean sink), target, internalformat, sink)
DEF_GLX_PROTO(void, glResetMinmax,(GLenum target), target)
DEF_GLX_PROTO(void, glGetMinmax,(GLenum target, GLboolean reset, GLenum format, GLenum types, GLvoid *values), target, reset, format, types, values)
DEF_GLX_PROTO(void, glGetMinmaxParameterfv,(GLenum target, GLenum pname, GLfloat *params), target, pname, params)
DEF_GLX_PROTO(void, glGetMinmaxParameteriv,(GLenum target, GLenum pname, GLint *params), target, pname, params)
DEF_GLX_PROTO(void, glConvolutionFilter1D,(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const GLvoid *image), target, internalformat, width, format, type, image)
DEF_GLX_PROTO(void, glConvolutionFilter2D,(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const GLvoid *image), target, internalformat, width, height, format, type, image)
DEF_GLX_PROTO(void, glConvolutionParameterf,(GLenum target, GLenum pname, GLfloat params), target, pname, params)
DEF_GLX_PROTO(void, glConvolutionParameterfv,(GLenum target, GLenum pname, const GLfloat *params), target, pname, params)
DEF_GLX_PROTO(void, glConvolutionParameteri,(GLenum target, GLenum pname, GLint params), target, pname, params)
DEF_GLX_PROTO(void, glConvolutionParameteriv,(GLenum target, GLenum pname, const GLint *params), target, pname, params)
DEF_GLX_PROTO(void, glCopyConvolutionFilter1D,(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width), target, internalformat, x, y, width)
DEF_GLX_PROTO(void, glCopyConvolutionFilter2D,(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height), target, internalformat, x, y, width, height)
DEF_GLX_PROTO(void, glGetConvolutionFilter,(GLenum target, GLenum format, GLenum type, GLvoid *image), target, format, type, image)
DEF_GLX_PROTO(void, glGetConvolutionParameterfv,(GLenum target, GLenum pname, GLfloat *params), target, pname, params)
DEF_GLX_PROTO(void, glGetConvolutionParameteriv,(GLenum target, GLenum pname, GLint *params), target, pname, params)
DEF_GLX_PROTO(void, glSeparableFilter2D,(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const GLvoid *row, const GLvoid *column), target, internalformat, width, height, format, type, row, column)
DEF_GLX_PROTO(void, glGetSeparableFilter,(GLenum target, GLenum format, GLenum type, GLvoid *row, GLvoid *column, GLvoid *span), target, format, type, row, column, span)
DEF_GLX_PROTO(void, glActiveTexture,(GLenum texture), texture)
DEF_GLX_PROTO(void, glClientActiveTexture,(GLenum texture), texture)
DEF_GLX_PROTO(void, glCompressedTexImage1D,(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const GLvoid *data), target, level, internalformat, width, border, imageSize, data)
DEF_GLX_PROTO(void, glCompressedTexImage2D,(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const GLvoid *data), target, level, internalformat, width, height, border, imageSize, data)
DEF_GLX_PROTO(void, glCompressedTexImage3D,(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const GLvoid *data), target, level, internalformat, width, height, depth, border, imageSize, data)
DEF_GLX_PROTO(void, glCompressedTexSubImage1D,(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const GLvoid *data), target, level, xoffset, width, format, imageSize, data)
DEF_GLX_PROTO(void, glCompressedTexSubImage2D,(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const GLvoid *data), target, level, xoffset, yoffset, width, height, format, imageSize, data)
DEF_GLX_PROTO(void, glCompressedTexSubImage3D,(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const GLvoid *data), target, level, xoffset, yoffset, zoffset, width, height, depth, format, imageSize, data)
DEF_GLX_PROTO(void, glGetCompressedTexImage,(GLenum target, GLint lod, GLvoid *img), target, lod, img)
DEF_GLX_PROTO(void, glMultiTexCoord1d,(GLenum target, GLdouble s), target, s)
DEF_GLX_PROTO(void, glMultiTexCoord1dv,(GLenum target, const GLdouble *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord1f,(GLenum target, GLfloat s), target, s)
DEF_GLX_PROTO(void, glMultiTexCoord1fv,(GLenum target, const GLfloat *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord1i,(GLenum target, GLint s), target, s)
DEF_GLX_PROTO(void, glMultiTexCoord1iv,(GLenum target, const GLint *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord1s,(GLenum target, GLshort s), target, s)
DEF_GLX_PROTO(void, glMultiTexCoord1sv,(GLenum target, const GLshort *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord2d,(GLenum target, GLdouble s, GLdouble t), target, s, t)
DEF_GLX_PROTO(void, glMultiTexCoord2dv,(GLenum target, const GLdouble *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord2f,(GLenum target, GLfloat s, GLfloat t), target, s, t)
DEF_GLX_PROTO(void, glMultiTexCoord2fv,(GLenum target, const GLfloat *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord2i,(GLenum target, GLint s, GLint t), target, s, t)
DEF_GLX_PROTO(void, glMultiTexCoord2iv,(GLenum target, const GLint *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord2s,(GLenum target, GLshort s, GLshort t), target, s, t)
DEF_GLX_PROTO(void, glMultiTexCoord2sv,(GLenum target, const GLshort *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord3d,(GLenum target, GLdouble s, GLdouble t, GLdouble r), target, s, t, r)
DEF_GLX_PROTO(void, glMultiTexCoord3dv,(GLenum target, const GLdouble *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord3f,(GLenum target, GLfloat s, GLfloat t, GLfloat r), target, s, t, r)
DEF_GLX_PROTO(void, glMultiTexCoord3fv,(GLenum target, const GLfloat *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord3i,(GLenum target, GLint s, GLint t, GLint r), target, s, t, r)
DEF_GLX_PROTO(void, glMultiTexCoord3iv,(GLenum target, const GLint *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord3s,(GLenum target, GLshort s, GLshort t, GLshort r), target, s, t, r)
DEF_GLX_PROTO(void, glMultiTexCoord3sv,(GLenum target, const GLshort *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord4d,(GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q), target, s, t, r, q)
DEF_GLX_PROTO(void, glMultiTexCoord4dv,(GLenum target, const GLdouble *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord4f,(GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q), target, s, t, r, q)
DEF_GLX_PROTO(void, glMultiTexCoord4fv,(GLenum target, const GLfloat *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord4i,(GLenum target, GLint s, GLint t, GLint r, GLint q), target, s, t, r, q)
DEF_GLX_PROTO(void, glMultiTexCoord4iv,(GLenum target, const GLint *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord4s,(GLenum target, GLshort s, GLshort t, GLshort r, GLshort q), target, s, t, r, q)
DEF_GLX_PROTO(void, glMultiTexCoord4sv,(GLenum target, const GLshort *v), target, v)
DEF_GLX_PROTO(void, glLoadTransposeMatrixd,(const GLdouble m[16]), m)
DEF_GLX_PROTO(void, glLoadTransposeMatrixf,(const GLfloat m[16]), m)
DEF_GLX_PROTO(void, glMultTransposeMatrixd,(const GLdouble m[16]), m)
DEF_GLX_PROTO(void, glMultTransposeMatrixf,(const GLfloat m[16]), m)
DEF_GLX_PROTO(void, glSampleCoverage,(GLclampf value, GLboolean invert), value, invert)
DEF_GLX_PROTO(void, glActiveTextureARB,(GLenum texture), texture)
DEF_GLX_PROTO(void, glClientActiveTextureARB,(GLenum texture), texture)
DEF_GLX_PROTO(void, glMultiTexCoord1dARB,(GLenum target, GLdouble s), target, s)
DEF_GLX_PROTO(void, glMultiTexCoord1dvARB,(GLenum target, const GLdouble *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord1fARB,(GLenum target, GLfloat s), target, s)
DEF_GLX_PROTO(void, glMultiTexCoord1fvARB,(GLenum target, const GLfloat *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord1iARB,(GLenum target, GLint s), target, s)
DEF_GLX_PROTO(void, glMultiTexCoord1ivARB,(GLenum target, const GLint *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord1sARB,(GLenum target, GLshort s), target, s)
DEF_GLX_PROTO(void, glMultiTexCoord1svARB,(GLenum target, const GLshort *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord2dARB,(GLenum target, GLdouble s, GLdouble t), target, s, t)
DEF_GLX_PROTO(void, glMultiTexCoord2dvARB,(GLenum target, const GLdouble *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord2fARB,(GLenum target, GLfloat s, GLfloat t), target, s, t)
DEF_GLX_PROTO(void, glMultiTexCoord2fvARB,(GLenum target, const GLfloat *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord2iARB,(GLenum target, GLint s, GLint t), target, s, t)
DEF_GLX_PROTO(void, glMultiTexCoord2ivARB,(GLenum target, const GLint *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord2sARB,(GLenum target, GLshort s, GLshort t), target, s, t)
DEF_GLX_PROTO(void, glMultiTexCoord2svARB,(GLenum target, const GLshort *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord3dARB,(GLenum target, GLdouble s, GLdouble t, GLdouble r), target, s, t, r)
DEF_GLX_PROTO(void, glMultiTexCoord3dvARB,(GLenum target, const GLdouble *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord3fARB,(GLenum target, GLfloat s, GLfloat t, GLfloat r), target, s, t, r)
DEF_GLX_PROTO(void, glMultiTexCoord3fvARB,(GLenum target, const GLfloat *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord3iARB,(GLenum target, GLint s, GLint t, GLint r), target, s, t, r)
DEF_GLX_PROTO(void, glMultiTexCoord3ivARB,(GLenum target, const GLint *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord3sARB,(GLenum target, GLshort s, GLshort t, GLshort r), target, s, t, r)
DEF_GLX_PROTO(void, glMultiTexCoord3svARB,(GLenum target, const GLshort *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord4dARB,(GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q), target, s, t, r, q)
DEF_GLX_PROTO(void, glMultiTexCoord4dvARB,(GLenum target, const GLdouble *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord4fARB,(GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q), target, s, t, r, q)
DEF_GLX_PROTO(void, glMultiTexCoord4fvARB,(GLenum target, const GLfloat *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord4iARB,(GLenum target, GLint s, GLint t, GLint r, GLint q), target, s, t, r, q)
DEF_GLX_PROTO(void, glMultiTexCoord4ivARB,(GLenum target, const GLint *v), target, v)
DEF_GLX_PROTO(void, glMultiTexCoord4sARB,(GLenum target, GLshort s, GLshort t, GLshort r, GLshort q), target, s, t, r, q)
DEF_GLX_PROTO(void, glMultiTexCoord4svARB,(GLenum target, const GLshort *v), target, v)
