P(glActiveProgramEXT)
P(glAlphaFragmentOp1ATI)
P(glAlphaFragmentOp2ATI)
P(glAlphaFragmentOp3ATI)
P(glAreProgramsResidentNV)
P(glAreTexturesResidentEXT)
P(glArrayElementEXT)
P(glAttachObjectARB)
P(glAttachShader)
P(glBeginConditionalRender)
P(glBeginConditionalRenderNV)
P(glBeginFragmentShaderATI)
P(glBeginQuery)
P(glBeginQueryARB)
P(glBeginQueryIndexed)
P(glBeginTransformFeedback)
P(glBeginTransformFeedbackEXT)
P(glBindAttribLocation)
P(glBindAttribLocationARB)
P(glBindBuffer)
P(glBindBufferARB)
P(glBindBufferBase)
P(glBindBufferBaseEXT)
P(glBindBufferOffsetEXT)
P(glBindBufferRange)
P(glBindBufferRangeEXT)
P(glBindFragDataLocation)
P(glBindFragDataLocationEXT)
P(glBindFragDataLocationIndexed)
P(glBindFragmentShaderATI)
P(glBindFramebuffer)
P(glBindFramebufferEXT)
P(glBindProgramARB)
P(glBindProgramNV)
P(glBindRenderbuffer)
P(glBindRenderbufferEXT)
P(glBindSampler)
P(glBindTextureEXT)
P(glBindTransformFeedback)
P(glBindVertexArray)
P(glBindVertexArrayOES)
P(glBlendColorEXT)
P(glBlendEquationEXT)
P(glBlendEquationIndexedAMD)
P(glBlendEquationSeparate)
P(glBlendEquationSeparateIndexedAMD)
P(glBlendEquationSeparateiARB)
P(glBlendEquationiARB)
P(glBlendFuncIndexedAMD)
P(glBlendFuncSeparate)
P(glBlendFuncSeparateEXT)
P(glBlendFuncSeparateIndexedAMD)
P(glBlendFuncSeparateiARB)
P(glBlendFunciARB)
P(glBlitFramebuffer)
P(glBufferData)
P(glBufferDataARB)
P(glBufferSubData)
P(glBufferSubDataARB)
P(glCheckFramebufferStatus)
P(glCheckFramebufferStatusEXT)
P(glClampColor)
P(glClampColorARB)
P(glClearBufferfi)
P(glClearBufferfv)
P(glClearBufferiv)
P(glClearBufferuiv)
P(glClearColorIiEXT)
P(glClearColorIuiEXT)
P(glClearDepthf)
P(glClientWaitSync)
P(glColorFragmentOp1ATI)
P(glColorFragmentOp2ATI)
P(glColorFragmentOp3ATI)
P(glColorMaskIndexedEXT)
P(glColorMaski)
P(glColorP3ui)
P(glColorP3uiv)
P(glColorP4ui)
P(glColorP4uiv)
P(glColorPointerEXT)
P(glColorTableEXT)
P(glCompileShader)
P(glCompileShaderARB)
P(glCompressedTexImage1DARB)
P(glCompressedTexImage2DARB)
P(glCompressedTexImage3DARB)
P(glCompressedTexSubImage1DARB)
P(glCompressedTexSubImage2DARB)
P(glCompressedTexSubImage3DARB)
P(glCopyBufferSubData)
P(glCopyTexImage1DEXT)
P(glCopyTexImage2DEXT)
P(glCopyTexSubImage1DEXT)
P(glCopyTexSubImage2DEXT)
P(glCopyTexSubImage3DEXT)
P(glCreateProgram)
P(glCreateProgramObjectARB)
P(glCreateShader)
P(glCreateShaderObjectARB)
P(glCreateShaderProgramEXT)
P(glDebugMessageCallbackARB)
P(glDebugMessageControlARB)
P(glDebugMessageInsertARB)
P(glDeleteBuffers)
P(glDeleteBuffersARB)
P(glDeleteFragmentShaderATI)
P(glDeleteFramebuffers)
P(glDeleteFramebuffersEXT)
P(glDeleteObjectARB)
P(glDeleteProgram)
P(glDeleteProgramsARB)
P(glDeleteProgramsNV)
P(glDeleteQueries)
P(glDeleteQueriesARB)
P(glDeleteRenderbuffers)
P(glDeleteRenderbuffersEXT)
P(glDeleteSamplers)
P(glDeleteShader)
P(glDeleteSync)
P(glDeleteTexturesEXT)
P(glDeleteTransformFeedbacks)
P(glDeleteVertexArrays)
P(glDeleteVertexArraysOES)
P(glDepthRangef)
P(glDetachObjectARB)
P(glDetachShader)
P(glDisableIndexedEXT)
P(glDisableVertexAttribArray)
P(glDisableVertexAttribArrayARB)
P(glDisablei)
P(glDrawArraysEXT)
P(glDrawArraysInstanced)
P(glDrawArraysInstancedARB)
P(glDrawArraysInstancedBaseInstance)
P(glDrawArraysInstancedEXT)
P(glDrawBuffers)
P(glDrawBuffersARB)
P(glDrawBuffersATI)
P(glDrawBuffersNV)
P(glDrawElementsBaseVertex)
P(glDrawElementsInstanced)
P(glDrawElementsInstancedARB)
P(glDrawElementsInstancedBaseInstance)
P(glDrawElementsInstancedBaseVertex)
P(glDrawElementsInstancedBaseVertexBaseInstance)
P(glDrawElementsInstancedEXT)
P(glDrawRangeElementsBaseVertex)
P(glDrawRangeElementsEXT)
P(glDrawTransformFeedback)
P(glDrawTransformFeedbackInstanced)
P(glDrawTransformFeedbackStream)
P(glDrawTransformFeedbackStreamInstanced)
P(glEGLImageTargetRenderbufferStorageOES)
P(glEGLImageTargetTexture2DOES)
P(glEdgeFlagPointerEXT)
P(glEnableIndexedEXT)
P(glEnableVertexAttribArray)
P(glEnableVertexAttribArrayARB)
P(glEnablei)
P(glEndConditionalRender)
P(glEndConditionalRenderNV)
P(glEndFragmentShaderATI)
P(glEndQuery)
P(glEndQueryARB)
P(glEndQueryIndexed)
P(glEndTransformFeedback)
P(glEndTransformFeedbackEXT)
P(glExecuteProgramNV)
P(glFenceSync)
P(glFlushMappedBufferRange)
P(glFogCoordPointer)
P(glFogCoordPointerEXT)
P(glFogCoordd)
P(glFogCoorddEXT)
P(glFogCoorddv)
P(glFogCoorddvEXT)
P(glFogCoordf)
P(glFogCoordfEXT)
P(glFogCoordfv)
P(glFogCoordfvEXT)
P(glFramebufferRenderbuffer)
P(glFramebufferRenderbufferEXT)
P(glFramebufferTexture)
P(glFramebufferTexture1D)
P(glFramebufferTexture1DEXT)
P(glFramebufferTexture2D)
P(glFramebufferTexture2DEXT)
P(glFramebufferTexture3D)
P(glFramebufferTexture3DEXT)
P(glFramebufferTextureARB)
P(glFramebufferTextureFaceARB)
P(glFramebufferTextureLayer)
P(glFramebufferTextureLayerARB)
P(glFramebufferTextureLayerEXT)
P(glGenBuffers)
P(glGenBuffersARB)
P(glGenFragmentShadersATI)
P(glGenFramebuffers)
P(glGenFramebuffersEXT)
P(glGenProgramsARB)
P(glGenProgramsNV)
P(glGenQueries)
P(glGenQueriesARB)
P(glGenRenderbuffers)
P(glGenRenderbuffersEXT)
P(glGenSamplers)
P(glGenTexturesEXT)
P(glGenTransformFeedbacks)
P(glGenVertexArrays)
P(glGenVertexArraysOES)
P(glGenerateMipmap)
P(glGenerateMipmapEXT)
P(glGetActiveAttrib)
P(glGetActiveAttribARB)
P(glGetActiveUniform)
P(glGetActiveUniformARB)
P(glGetActiveUniformBlockName)
P(glGetActiveUniformBlockiv)
P(glGetActiveUniformName)
P(glGetActiveUniformsiv)
P(glGetAttachedObjectsARB)
P(glGetAttachedShaders)
P(glGetAttribLocation)
P(glGetAttribLocationARB)
P(glGetBooleanIndexedvEXT)
P(glGetBooleani_v)
P(glGetBufferParameteri64v)
P(glGetBufferParameteriv)
P(glGetBufferParameterivARB)
P(glGetBufferPointerv)
P(glGetBufferPointervARB)
P(glGetBufferSubData)
P(glGetBufferSubDataARB)
P(glGetColorTableEXT)
P(glGetColorTableParameterfvEXT)
P(glGetColorTableParameterivEXT)
P(glGetCompressedTexImageARB)
P(glGetDebugMessageLogARB)
P(glGetFragDataIndex)
P(glGetFragDataLocation)
P(glGetFragDataLocationEXT)
P(glGetFramebufferAttachmentParameteriv)
P(glGetFramebufferAttachmentParameterivEXT)
P(glGetGraphicsResetStatusARB)
P(glGetHandleARB)
P(glGetInfoLogARB)
P(glGetInteger64i_v)
P(glGetInteger64v)
P(glGetIntegerIndexedvEXT)
P(glGetIntegeri_v)
P(glGetObjectParameterfvARB)
P(glGetObjectParameterivAPPLE)
P(glGetObjectParameterivARB)
P(glGetPointervEXT)
P(glGetProgramEnvParameterdvARB)
P(glGetProgramEnvParameterfvARB)
P(glGetProgramInfoLog)
P(glGetProgramLocalParameterdvARB)
P(glGetProgramLocalParameterfvARB)
P(glGetProgramNamedParameterdvNV)
P(glGetProgramNamedParameterfvNV)
P(glGetProgramParameterdvNV)
P(glGetProgramParameterfvNV)
P(glGetProgramStringARB)
P(glGetProgramStringNV)
P(glGetProgramiv)
P(glGetProgramivARB)
P(glGetProgramivNV)
P(glGetQueryIndexediv)
P(glGetQueryObjectiv)
P(glGetQueryObjectivARB)
P(glGetQueryObjectuiv)
P(glGetQueryObjectuivARB)
P(glGetQueryiv)
P(glGetQueryivARB)
P(glGetRenderbufferParameteriv)
P(glGetRenderbufferParameterivEXT)
P(glGetSamplerParameterIiv)
P(glGetSamplerParameterIuiv)
P(glGetSamplerParameterfv)
P(glGetSamplerParameteriv)
P(glGetShaderInfoLog)
P(glGetShaderPrecisionFormat)
P(glGetShaderSource)
P(glGetShaderSourceARB)
P(glGetShaderiv)
P(glGetStringi)
P(glGetSynciv)
P(glGetTexBumpParameterfvATI)
P(glGetTexBumpParameterivATI)
P(glGetTexParameterIiv)
P(glGetTexParameterIivEXT)
P(glGetTexParameterIuiv)
P(glGetTexParameterIuivEXT)
P(glGetTrackMatrixivNV)
P(glGetTransformFeedbackVarying)
P(glGetTransformFeedbackVaryingEXT)
P(glGetUniformBlockIndex)
P(glGetUniformIndices)
P(glGetUniformLocation)
P(glGetUniformLocationARB)
P(glGetUniformfv)
P(glGetUniformfvARB)
P(glGetUniformiv)
P(glGetUniformivARB)
P(glGetUniformuiv)
P(glGetUniformuivEXT)
P(glGetVertexAttribIiv)
P(glGetVertexAttribIivEXT)
P(glGetVertexAttribIuiv)
P(glGetVertexAttribIuivEXT)
P(glGetVertexAttribPointerv)
P(glGetVertexAttribPointervARB)
P(glGetVertexAttribPointervNV)
P(glGetVertexAttribdv)
P(glGetVertexAttribdvARB)
P(glGetVertexAttribdvNV)
P(glGetVertexAttribfv)
P(glGetVertexAttribfvARB)
P(glGetVertexAttribfvNV)
P(glGetVertexAttribiv)
P(glGetVertexAttribivARB)
P(glGetVertexAttribivNV)
P(glGetnColorTableARB)
P(glGetnCompressedTexImageARB)
P(glGetnConvolutionFilterARB)
P(glGetnHistogramARB)
P(glGetnMapdvARB)
P(glGetnMapfvARB)
P(glGetnMapivARB)
P(glGetnMinmaxARB)
P(glGetnPixelMapfvARB)
P(glGetnPixelMapuivARB)
P(glGetnPixelMapusvARB)
P(glGetnPolygonStippleARB)
P(glGetnSeparableFilterARB)
P(glGetnTexImageARB)
P(glGetnUniformdvARB)
P(glGetnUniformfvARB)
P(glGetnUniformivARB)
P(glGetnUniformuivARB)
P(glIndexPointerEXT)
P(glInvalidateBufferData)
P(glInvalidateBufferSubData)
P(glInvalidateFramebuffer)
P(glInvalidateSubFramebuffer)
P(glInvalidateTexImage)
P(glInvalidateTexSubImage)
P(glIsBuffer)
P(glIsBufferARB)
P(glIsEnabledIndexedEXT)
P(glIsEnabledi)
P(glIsFramebuffer)
P(glIsFramebufferEXT)
P(glIsProgram)
P(glIsProgramARB)
P(glIsProgramNV)
P(glIsQuery)
P(glIsQueryARB)
P(glIsRenderbuffer)
P(glIsRenderbufferEXT)
P(glIsSampler)
P(glIsShader)
P(glIsSync)
P(glIsTextureEXT)
P(glIsTransformFeedback)
P(glIsVertexArray)
P(glIsVertexArrayOES)
P(glLinkProgram)
P(glLinkProgramARB)
P(glLoadProgramNV)
P(glLoadTransposeMatrixdARB)
P(glLoadTransposeMatrixfARB)
P(glLockArraysEXT)
P(glMapBuffer)
P(glMapBufferARB)
P(glMapBufferRange)
P(glMultTransposeMatrixdARB)
P(glMultTransposeMatrixfARB)
P(glMultiDrawArrays)
P(glMultiDrawArraysEXT)
P(glMultiDrawElements)
P(glMultiDrawElementsBaseVertex)
P(glMultiDrawElementsEXT)
P(glMultiTexCoordP1ui)
P(glMultiTexCoordP1uiv)
P(glMultiTexCoordP2ui)
P(glMultiTexCoordP2uiv)
P(glMultiTexCoordP3ui)
P(glMultiTexCoordP3uiv)
P(glMultiTexCoordP4ui)
P(glMultiTexCoordP4uiv)
P(glNormalP3ui)
P(glNormalP3uiv)
P(glNormalPointerEXT)
P(glObjectPurgeableAPPLE)
P(glObjectUnpurgeableAPPLE)
P(glPassTexCoordATI)
P(glPauseTransformFeedback)
P(glPointParameterf)
P(glPointParameterfARB)
P(glPointParameterfEXT)
P(glPointParameterfv)
P(glPointParameterfvARB)
P(glPointParameterfvEXT)
P(glPointParameteri)
P(glPointParameteriNV)
P(glPointParameteriv)
P(glPointParameterivNV)
P(glPolygonOffsetEXT)
P(glPrimitiveRestartIndex)
P(glPrimitiveRestartIndexNV)
P(glPrimitiveRestartNV)
P(glPrioritizeTexturesEXT)
P(glProgramEnvParameter4dARB)
P(glProgramEnvParameter4dvARB)
P(glProgramEnvParameter4fARB)
P(glProgramEnvParameter4fvARB)
P(glProgramLocalParameter4dARB)
P(glProgramLocalParameter4dvARB)
P(glProgramLocalParameter4fARB)
P(glProgramLocalParameter4fvARB)
P(glProgramNamedParameter4dNV)
P(glProgramNamedParameter4dvNV)
P(glProgramNamedParameter4fNV)
P(glProgramNamedParameter4fvNV)
P(glProgramParameter4dNV)
P(glProgramParameter4dvNV)
P(glProgramParameter4fNV)
P(glProgramParameter4fvNV)
P(glProgramParameteriARB)
P(glProgramParameters4dvNV)
P(glProgramParameters4fvNV)
P(glProgramStringARB)
P(glProvokingVertex)
P(glProvokingVertexEXT)
P(glReadBufferNV)
P(glReadnPixelsARB)
P(glReleaseShaderCompiler)
P(glRenderbufferStorage)
P(glRenderbufferStorageEXT)
P(glRenderbufferStorageMultisample)
P(glRenderbufferStorageMultisampleEXT)
P(glRequestResidentProgramsNV)
P(glResumeTransformFeedback)
P(glSampleCoverageARB)
P(glSampleMapATI)
P(glSamplerParameterIiv)
P(glSamplerParameterIuiv)
P(glSamplerParameterf)
P(glSamplerParameterfv)
P(glSamplerParameteri)
P(glSamplerParameteriv)
P(glSecondaryColor3b)
P(glSecondaryColor3bEXT)
P(glSecondaryColor3bv)
P(glSecondaryColor3bvEXT)
P(glSecondaryColor3d)
P(glSecondaryColor3dEXT)
P(glSecondaryColor3dv)
P(glSecondaryColor3dvEXT)
P(glSecondaryColor3f)
P(glSecondaryColor3fEXT)
P(glSecondaryColor3fv)
P(glSecondaryColor3fvEXT)
P(glSecondaryColor3i)
P(glSecondaryColor3iEXT)
P(glSecondaryColor3iv)
P(glSecondaryColor3ivEXT)
P(glSecondaryColor3s)
P(glSecondaryColor3sEXT)
P(glSecondaryColor3sv)
P(glSecondaryColor3svEXT)
P(glSecondaryColor3ub)
P(glSecondaryColor3ubEXT)
P(glSecondaryColor3ubv)
P(glSecondaryColor3ubvEXT)
P(glSecondaryColor3ui)
P(glSecondaryColor3uiEXT)
P(glSecondaryColor3uiv)
P(glSecondaryColor3uivEXT)
P(glSecondaryColor3us)
P(glSecondaryColor3usEXT)
P(glSecondaryColor3usv)
P(glSecondaryColor3usvEXT)
P(glSecondaryColorP3ui)
P(glSecondaryColorP3uiv)
P(glSecondaryColorPointer)
P(glSecondaryColorPointerEXT)
P(glSetFragmentShaderConstantATI)
P(glShaderBinary)
P(glShaderSource)
P(glShaderSourceARB)
P(glStencilFuncSeparate)
P(glStencilMaskSeparate)
P(glStencilOpSeparate)
P(glTexBuffer)
P(glTexBufferARB)
P(glTexBumpParameterfvATI)
P(glTexBumpParameterivATI)
P(glTexCoordP1ui)
P(glTexCoordP1uiv)
P(glTexCoordP2ui)
P(glTexCoordP2uiv)
P(glTexCoordP3ui)
P(glTexCoordP3uiv)
P(glTexCoordP4ui)
P(glTexCoordP4uiv)
P(glTexCoordPointerEXT)
P(glTexImage3DEXT)
P(glTexParameterIiv)
P(glTexParameterIivEXT)
P(glTexParameterIuiv)
P(glTexParameterIuivEXT)
P(glTexStorage1D)
P(glTexStorage2D)
P(glTexStorage3D)
P(glTexSubImage1DEXT)
P(glTexSubImage2DEXT)
P(glTexSubImage3DEXT)
P(glTextureBarrierNV)
P(glTextureStorage1DEXT)
P(glTextureStorage2DEXT)
P(glTextureStorage3DEXT)
P(glTrackMatrixNV)
P(glTransformFeedbackVaryings)
P(glTransformFeedbackVaryingsEXT)
P(glUniform1f)
P(glUniform1fARB)
P(glUniform1fv)
P(glUniform1fvARB)
P(glUniform1i)
P(glUniform1iARB)
P(glUniform1iv)
P(glUniform1ivARB)
P(glUniform1ui)
P(glUniform1uiEXT)
P(glUniform1uiv)
P(glUniform1uivEXT)
P(glUniform2f)
P(glUniform2fARB)
P(glUniform2fv)
P(glUniform2fvARB)
P(glUniform2i)
P(glUniform2iARB)
P(glUniform2iv)
P(glUniform2ivARB)
P(glUniform2ui)
P(glUniform2uiEXT)
P(glUniform2uiv)
P(glUniform2uivEXT)
P(glUniform3f)
P(glUniform3fARB)
P(glUniform3fv)
P(glUniform3fvARB)
P(glUniform3i)
P(glUniform3iARB)
P(glUniform3iv)
P(glUniform3ivARB)
P(glUniform3ui)
P(glUniform3uiEXT)
P(glUniform3uiv)
P(glUniform3uivEXT)
P(glUniform4f)
P(glUniform4fARB)
P(glUniform4fv)
P(glUniform4fvARB)
P(glUniform4i)
P(glUniform4iARB)
P(glUniform4iv)
P(glUniform4ivARB)
P(glUniform4ui)
P(glUniform4uiEXT)
P(glUniform4uiv)
P(glUniform4uivEXT)
P(glUniformBlockBinding)
P(glUniformMatrix2fv)
P(glUniformMatrix2fvARB)
P(glUniformMatrix2x3fv)
P(glUniformMatrix2x4fv)
P(glUniformMatrix3fv)
P(glUniformMatrix3fvARB)
P(glUniformMatrix3x2fv)
P(glUniformMatrix3x4fv)
P(glUniformMatrix4fv)
P(glUniformMatrix4fvARB)
P(glUniformMatrix4x2fv)
P(glUniformMatrix4x3fv)
P(glUnlockArraysEXT)
P(glUnmapBuffer)
P(glUnmapBufferARB)
P(glUseProgram)
P(glUseProgramObjectARB)
P(glUseShaderProgramEXT)
P(glValidateProgram)
P(glValidateProgramARB)
P(glVertexAttrib1d)
P(glVertexAttrib1dARB)
P(glVertexAttrib1dNV)
P(glVertexAttrib1dv)
P(glVertexAttrib1dvARB)
P(glVertexAttrib1dvNV)
P(glVertexAttrib1f)
P(glVertexAttrib1fARB)
P(glVertexAttrib1fNV)
P(glVertexAttrib1fv)
P(glVertexAttrib1fvARB)
P(glVertexAttrib1fvNV)
P(glVertexAttrib1s)
P(glVertexAttrib1sARB)
P(glVertexAttrib1sNV)
P(glVertexAttrib1sv)
P(glVertexAttrib1svARB)
P(glVertexAttrib1svNV)
P(glVertexAttrib2d)
P(glVertexAttrib2dARB)
P(glVertexAttrib2dNV)
P(glVertexAttrib2dv)
P(glVertexAttrib2dvARB)
P(glVertexAttrib2dvNV)
P(glVertexAttrib2f)
P(glVertexAttrib2fARB)
P(glVertexAttrib2fNV)
P(glVertexAttrib2fv)
P(glVertexAttrib2fvARB)
P(glVertexAttrib2fvNV)
P(glVertexAttrib2s)
P(glVertexAttrib2sARB)
P(glVertexAttrib2sNV)
P(glVertexAttrib2sv)
P(glVertexAttrib2svARB)
P(glVertexAttrib2svNV)
P(glVertexAttrib3d)
P(glVertexAttrib3dARB)
P(glVertexAttrib3dNV)
P(glVertexAttrib3dv)
P(glVertexAttrib3dvARB)
P(glVertexAttrib3dvNV)
P(glVertexAttrib3f)
P(glVertexAttrib3fARB)
P(glVertexAttrib3fNV)
P(glVertexAttrib3fv)
P(glVertexAttrib3fvARB)
P(glVertexAttrib3fvNV)
P(glVertexAttrib3s)
P(glVertexAttrib3sARB)
P(glVertexAttrib3sNV)
P(glVertexAttrib3sv)
P(glVertexAttrib3svARB)
P(glVertexAttrib3svNV)
P(glVertexAttrib4Nbv)
P(glVertexAttrib4NbvARB)
P(glVertexAttrib4Niv)
P(glVertexAttrib4NivARB)
P(glVertexAttrib4Nsv)
P(glVertexAttrib4NsvARB)
P(glVertexAttrib4Nub)
P(glVertexAttrib4NubARB)
P(glVertexAttrib4Nubv)
P(glVertexAttrib4NubvARB)
P(glVertexAttrib4Nuiv)
P(glVertexAttrib4NuivARB)
P(glVertexAttrib4Nusv)
P(glVertexAttrib4NusvARB)
P(glVertexAttrib4bv)
P(glVertexAttrib4bvARB)
P(glVertexAttrib4d)
P(glVertexAttrib4dARB)
P(glVertexAttrib4dNV)
P(glVertexAttrib4dv)
P(glVertexAttrib4dvARB)
P(glVertexAttrib4dvNV)
P(glVertexAttrib4f)
P(glVertexAttrib4fARB)
P(glVertexAttrib4fNV)
P(glVertexAttrib4fv)
P(glVertexAttrib4fvARB)
P(glVertexAttrib4fvNV)
P(glVertexAttrib4iv)
P(glVertexAttrib4ivARB)
P(glVertexAttrib4s)
P(glVertexAttrib4sARB)
P(glVertexAttrib4sNV)
P(glVertexAttrib4sv)
P(glVertexAttrib4svARB)
P(glVertexAttrib4svNV)
P(glVertexAttrib4ubNV)
P(glVertexAttrib4ubv)
P(glVertexAttrib4ubvARB)
P(glVertexAttrib4ubvNV)
P(glVertexAttrib4uiv)
P(glVertexAttrib4uivARB)
P(glVertexAttrib4usv)
P(glVertexAttrib4usvARB)
P(glVertexAttribDivisor)
P(glVertexAttribDivisorARB)
P(glVertexAttribI1i)
P(glVertexAttribI1iEXT)
P(glVertexAttribI1iv)
P(glVertexAttribI1ivEXT)
P(glVertexAttribI1ui)
P(glVertexAttribI1uiEXT)
P(glVertexAttribI1uiv)
P(glVertexAttribI1uivEXT)
P(glVertexAttribI2i)
P(glVertexAttribI2iEXT)
P(glVertexAttribI2iv)
P(glVertexAttribI2ivEXT)
P(glVertexAttribI2ui)
P(glVertexAttribI2uiEXT)
P(glVertexAttribI2uiv)
P(glVertexAttribI2uivEXT)
P(glVertexAttribI3i)
P(glVertexAttribI3iEXT)
P(glVertexAttribI3iv)
P(glVertexAttribI3ivEXT)
P(glVertexAttribI3ui)
P(glVertexAttribI3uiEXT)
P(glVertexAttribI3uiv)
P(glVertexAttribI3uivEXT)
P(glVertexAttribI4bv)
P(glVertexAttribI4bvEXT)
P(glVertexAttribI4i)
P(glVertexAttribI4iEXT)
P(glVertexAttribI4iv)
P(glVertexAttribI4ivEXT)
P(glVertexAttribI4sv)
P(glVertexAttribI4svEXT)
P(glVertexAttribI4ubv)
P(glVertexAttribI4ubvEXT)
P(glVertexAttribI4ui)
P(glVertexAttribI4uiEXT)
P(glVertexAttribI4uiv)
P(glVertexAttribI4uivEXT)
P(glVertexAttribI4usv)
P(glVertexAttribI4usvEXT)
P(glVertexAttribIPointer)
P(glVertexAttribIPointerEXT)
P(glVertexAttribP1ui)
P(glVertexAttribP1uiv)
P(glVertexAttribP2ui)
P(glVertexAttribP2uiv)
P(glVertexAttribP3ui)
P(glVertexAttribP3uiv)
P(glVertexAttribP4ui)
P(glVertexAttribP4uiv)
P(glVertexAttribPointer)
P(glVertexAttribPointerARB)
P(glVertexAttribPointerNV)
P(glVertexAttribs1dvNV)
P(glVertexAttribs1fvNV)
P(glVertexAttribs1svNV)
P(glVertexAttribs2dvNV)
P(glVertexAttribs2fvNV)
P(glVertexAttribs2svNV)
P(glVertexAttribs3dvNV)
P(glVertexAttribs3fvNV)
P(glVertexAttribs3svNV)
P(glVertexAttribs4dvNV)
P(glVertexAttribs4fvNV)
P(glVertexAttribs4svNV)
P(glVertexAttribs4ubvNV)
P(glVertexP2ui)
P(glVertexP2uiv)
P(glVertexP3ui)
P(glVertexP3uiv)
P(glVertexP4ui)
P(glVertexP4uiv)
P(glVertexPointerEXT)
P(glWaitSync)
P(glWindowPos2d)
P(glWindowPos2dARB)
P(glWindowPos2dv)
P(glWindowPos2dvARB)
P(glWindowPos2f)
P(glWindowPos2fARB)
P(glWindowPos2fv)
P(glWindowPos2fvARB)
P(glWindowPos2i)
P(glWindowPos2iARB)
P(glWindowPos2iv)
P(glWindowPos2ivARB)
P(glWindowPos2s)
P(glWindowPos2sARB)
P(glWindowPos2sv)
P(glWindowPos2svARB)
P(glWindowPos3d)
P(glWindowPos3dARB)
P(glWindowPos3dv)
P(glWindowPos3dvARB)
P(glWindowPos3f)
P(glWindowPos3fARB)
P(glWindowPos3fv)
P(glWindowPos3fvARB)
P(glWindowPos3i)
P(glWindowPos3iARB)
P(glWindowPos3iv)
P(glWindowPos3ivARB)
P(glWindowPos3s)
P(glWindowPos3sARB)
P(glWindowPos3sv)
P(glWindowPos3svARB)
